.. Metallurgy documentation master file, created by
   sphinx-quickstart on Fri Apr  8 10:44:15 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Metallurgy's documentation!
====================================

Metallurgy is a Python package for creating alloys of chemical
elements, and investigating their properties.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
